@@ -1,6 +1,7 @@
 use crate::devices::smartsocket::SmartSocket;
 use crate::devices::thermometer::Thermometer;
 
+#[derive(Debug)]
 pub enum DeviceType {
     SmartSocket(SmartSocket),
     Thermometer(Thermometer),
@@ -10,26 +11,20 @@ pub enum DeviceType {
 /// ```
 /// use cleverhouse_by_akrutikov::device::Device;
 /// pub struct SomeDevice {
-///    pub name: String,
 ///    pub description: String,
 /// };
 ///
 /// impl Device for SomeDevice {
-///     fn name(&self) -> &str {
-///         &*self.name
-///     }
 ///     fn description(&self) -> &str {
 ///         &*self.description
 ///     }
 /// }
 ///
-/// let device = SomeDevice { name: String::from("SomeDevice"), description: String::from("some device"),};
+/// let device = SomeDevice { description: String::from("some device"), };
 ///
-/// assert_eq!(device.name, device.name());
 /// assert_eq!(device.description, device.description());
 /// ```
 
 pub trait Device {
-    fn name(&self) -> &str;
     fn description(&self) -> &str;
 }
